@@ -66,7 +66,7 @@ NULL
 #' 
 #' See \code{\link[rebus.base]{ClassGroups}}.
 #' @name ClassGroups
-#' @aliases alnum alpha blank cntrl digit graph lower printable punct space upper hex_digit any_char dgt wrd spc not_dgt not_wrd not_spc ascii_digit ascii_lower ascii_upper ascii_alpha ascii_alnum char_range
+#' @aliases alnum alpha blank cntrl digit graph lower printable punct space upper hex_digit any_char grapheme newline dgt wrd spc not_dgt not_wrd not_spc ascii_digit ascii_lower ascii_upper ascii_alpha ascii_alnum char_range
 #' @export alnum
 #' @export alpha
 #' @export blank
@@ -80,6 +80,8 @@ NULL
 #' @export upper
 #' @export hex_digit
 #' @export any_char
+#' @export grapheme
+#' @export newline
 #' @export dgt
 #' @export wrd
 #' @export spc
@@ -130,7 +132,7 @@ NULL
 #' 
 #' See \code{\link[rebus.base]{CharacterClasses}}.
 #' @name CharacterClasses
-#' @aliases ALNUM ALPHA BLANK CNTRL DIGIT GRAPH LOWER PRINT PUNCT SPACE UPPER HEX_DIGIT ANY_CHAR DGT WRD SPC NOT_DGT NOT_WRD NOT_SPC ASCII_DIGIT ASCII_LOWER ASCII_UPPER ASCII_ALPHA ASCII_ALNUM UNMATCHABLE
+#' @aliases ALNUM ALPHA BLANK CNTRL DIGIT GRAPH LOWER PRINT PUNCT SPACE UPPER HEX_DIGIT ANY_CHAR GRAPHEME NEWLINE DGT WRD SPC NOT_DGT NOT_WRD NOT_SPC ASCII_DIGIT ASCII_LOWER ASCII_UPPER ASCII_ALPHA ASCII_ALNUM UNMATCHABLE
 #' @export ALNUM
 #' @export ALPHA
 #' @export BLANK
@@ -144,6 +146,8 @@ NULL
 #' @export UPPER
 #' @export HEX_DIGIT
 #' @export ANY_CHAR
+#' @export GRAPHEME
+#' @export NEWLINE
 #' @export DGT
 #' @export WRD
 #' @export SPC
@@ -266,6 +270,15 @@ NULL
 #' @export no_backslash_escaping
 NULL 
 
+#' Force the case of replacement values
+#' 
+#' See \code{\link[rebus.base]{ReplacementCase}}.
+#' @name ReplacementCase
+#' @aliases as_lower as_upper
+#' @export as_lower
+#' @export as_upper
+NULL 
+
 
 # From rebus.base regex-methods.R
 
